@@ -46,7 +46,10 @@ pub struct Config {
     pub ignore_panics: bool,
     /// Flag to add a clean step when preparing the target project
     #[serde(rename = "force-clean")]
-    pub force_clean: bool,
+    force_clean: bool,
+    /// The opposite of --force-clean
+    #[serde(rename = "skip-clean")]
+    skip_clean: bool,
     #[serde(rename = "all-targets")]
     pub all_targets: bool,
     /// Verbose flag for printing information to the user
@@ -163,6 +166,7 @@ pub struct Config {
     /// Colouring of logging
     pub color: Color,
     /// Follow traced executables down
+    #[serde(rename = "follow-exec")]
     pub follow_exec: bool,
     /// Number of jobs used for building the tests
     pub jobs: Option<usize>,
@@ -193,6 +197,7 @@ impl Default for Config {
             ignore_tests: false,
             ignore_panics: false,
             force_clean: true,
+            skip_clean: false,
             verbose: false,
             debug: false,
             follow_exec: false,
@@ -205,7 +210,7 @@ impl Default for Config {
             coveralls: None,
             ci_tool: None,
             report_uri: None,
-            forward_signals: false,
+            forward_signals: true,
             no_default_features: false,
             features: None,
             unstable_features: vec![],
@@ -283,6 +288,7 @@ impl<'a> From<&'a ArgMatches<'a>> for ConfigWrapper {
             ignore_tests: args.is_present("ignore-tests"),
             ignore_panics: args.is_present("ignore-panics"),
             force_clean,
+            skip_clean: !force_clean,
             no_fail_fast: args.is_present("no-fail-fast"),
             all_targets: args.is_present("all-targets"),
             follow_exec: args.is_present("follow-exec"),
@@ -297,7 +303,7 @@ impl<'a> From<&'a ArgMatches<'a>> for ConfigWrapper {
             coveralls: get_coveralls(args),
             ci_tool: get_ci(args),
             report_uri: get_report_uri(args),
-            forward_signals: args.is_present("forward"),
+            forward_signals: true, // No longer an option
             all_features: args.is_present("all-features"),
             no_default_features: args.is_present("no-default-features"),
             features,
@@ -367,6 +373,17 @@ impl Config {
         }
     }
 
+    pub fn set_clean(&mut self, clean: bool) {
+        self.force_clean = clean;
+        self.skip_clean = !clean;
+    }
+
+    pub fn force_clean(&self) -> bool {
+        // default is force clean true skip clean false. So if one isn't default we pick that one
+        // as precedence.
+        self.force_clean && !self.skip_clean
+    }
+
     pub fn target_dir(&self) -> PathBuf {
         if let Some(s) = &self.target_dir {
             s.clone()
@@ -376,7 +393,7 @@ impl Config {
                 _ => self
                     .manifest
                     .parent()
-                    .map(|x| x.to_path_buf())
+                    .map(Path::to_path_buf)
                     .unwrap_or_default()
                     .join("target"),
             }
@@ -406,7 +423,7 @@ impl Config {
             _ => self
                 .manifest
                 .parent()
-                .map(|x| x.to_path_buf())
+                .map(Path::to_path_buf)
                 .unwrap_or_default(),
         }
     }
@@ -428,7 +445,7 @@ impl Config {
 
     pub fn get_config_vec(file_configs: std::io::Result<Vec<Self>>, backup: Self) -> ConfigWrapper {
         if let Ok(mut confs) = file_configs {
-            for c in confs.iter_mut() {
+            for c in &mut confs {
                 c.merge(&backup);
             }
             if confs.is_empty() {
@@ -524,6 +541,7 @@ impl Config {
         self.no_run |= other.no_run;
         self.no_default_features |= other.no_default_features;
         self.ignore_panics |= other.ignore_panics;
+        // Since true is the default
         self.forward_signals |= other.forward_signals;
         self.run_ignored |= other.run_ignored;
         self.release |= other.release;
@@ -549,10 +567,24 @@ impl Config {
         self.all |= other.all;
         self.frozen |= other.frozen;
         self.locked |= other.locked;
-        self.force_clean |= other.force_clean;
+        // This is &= because force_clean true is the default. If one is false then that is
+        // non-default
+        self.force_clean &= other.force_clean;
+        self.skip_clean |= other.skip_clean;
         self.ignore_tests |= other.ignore_tests;
         self.no_fail_fast |= other.no_fail_fast;
 
+        // The two flags now don't agree, if one is set to non-default then prioritise that
+        match (self.force_clean, self.skip_clean) {
+            (true, false) | (false, true) => {}
+            (false, _) => {
+                self.skip_clean = true;
+            }
+            (_, true) => {
+                self.force_clean = false;
+            }
+        }
+
         let new_flags = match (self.rustflags.as_ref(), other.rustflags.as_ref()) {
             (Some(a), Some(b)) => Some(format!("{} {}", a, b)),
             (Some(a), None) => Some(a.clone()),
@@ -822,7 +854,7 @@ mod tests {
             .unwrap();
         let conf = ConfigWrapper::from(&matches).0;
         assert_eq!(conf.len(), 1);
-        assert_eq!(conf[0].features, Some("a b".to_string()))
+        assert_eq!(conf[0].features, Some("a b".to_string()));
     }
 
     #[test]
