@@ -8,6 +8,7 @@ use crate::report::report_coverage;
 use crate::source_analysis::{LineAnalysis, SourceAnalysis};
 use crate::test_loader::*;
 use crate::traces::*;
+use std::ffi::OsString;
 use std::fs::create_dir_all;
 use tracing::{debug, error, info, warn};
 use tracing_subscriber::{filter::LevelFilter, EnvFilter};
@@ -45,10 +46,10 @@ pub fn setup_logging(color: Color, debug: bool, verbose: bool) {
     // e.g. `RUST_LOG="trace" cargo-tarpaulin` will end up printing TRACE for everything
     // `cargo-tarpaulin -v` will print DEBUG for tarpaulin and INFO for everything else.
     // `RUST_LOG="error" cargo-tarpaulin -v` will print ERROR for everything.
-    let filter = match std::env::var_os(RUST_LOG_ENV).map(|s| s.into_string()) {
+    let filter = match std::env::var_os(RUST_LOG_ENV).map(OsString::into_string) {
         Some(Ok(env)) => {
             let mut filter = base_exceptions(EnvFilter::new(""));
-            for s in env.split(',').into_iter() {
+            for s in env.split(',') {
                 match s.parse() {
                     Ok(d) => filter = filter.add_directive(d),
                     Err(err) => println!("WARN ignoring log directive: `{}`: {}", s, err),
@@ -75,7 +76,7 @@ pub fn trace(configs: &[Config]) -> Result<TraceMap, RunError> {
     let mut tarpaulin_result = Ok(());
     let mut ret = 0i32;
     let logger = if configs.iter().any(|c| c.dump_traces) {
-        Some(EventLog::new())
+        Some(EventLog::new(configs.iter().map(|x| x.root()).collect()))
     } else {
         None
     };
@@ -201,7 +202,7 @@ pub fn launch_tarpaulin(
             if let Some(res) = coverage {
                 result.merge(&res.0);
                 return_code |= if exe.should_panic() {
-                    (res.1 == 0) as i32
+                    (res.1 == 0).into()
                 } else {
                     res.1
                 };
