@@ -42,7 +42,10 @@ pub fn get_test_coverage(
         warn!("Test at {} doesn't exist", test.path().display());
         return Ok(None);
     }
-    let cpus = Some(*NUM_CPUS);
+
+    // Solves CI issue when fixing #953 and #966 in PR #962
+    let threads = if config.follow_exec { 1 } else { *NUM_CPUS };
+
     if let Err(e) = limit_affinity() {
         warn!("Failed to set processor affinity {}", e);
     }
@@ -56,13 +59,13 @@ pub fn get_test_coverage(
                     Mode::Build => "binary",
                 };
                 info!("Launching {}", bin_type);
-                execute_test(test, ignored, config, cpus)?;
+                execute_test(test, ignored, config, Some(threads))?;
                 Ok(None)
             }
             Err(err) => Err(RunError::TestCoverage(format!(
                 "Failed to run test {}, Error: {}",
                 test.path().display(),
-                err.to_string()
+                err
             ))),
         }
     }
@@ -126,8 +129,8 @@ pub fn execute(
         .map(|x| CString::new(x.as_str()).unwrap_or_default())
         .collect::<Vec<CString>>();
 
-    let arg_ref = argv.iter().map(|x| x.as_ref()).collect::<Vec<&CStr>>();
-    let env_ref = envar.iter().map(|x| x.as_ref()).collect::<Vec<&CStr>>();
+    let arg_ref = argv.iter().map(AsRef::as_ref).collect::<Vec<&CStr>>();
+    let env_ref = envar.iter().map(AsRef::as_ref).collect::<Vec<&CStr>>();
     execve(&program, &arg_ref, &env_ref).map_err(|_| RunError::Internal)?;
 
     unreachable!();
