@@ -32,7 +32,7 @@ impl RunningProcessHandle {
         let child = cmd.spawn()?;
         let existing_profraws = fs::read_dir(config.root())?
             .into_iter()
-            .filter_map(|x| x.ok())
+            .filter_map(Result::ok)
             .filter(|x| x.path().is_file() && x.path().extension() == Some(OsStr::new("profraw")))
             .map(|x| x.path())
             .collect();
@@ -154,52 +154,27 @@ pub(crate) fn collect_coverage(
                     ret_code = i;
                 }
                 break;
+            } else if let Some(event_logger) = logger {
+                event_logger.push_marker();
             }
         }
     }
     Ok((traces, ret_code))
 }
 
-/// Launches the test executable
-fn execute_test(
-    test: &TestBinary,
-    ignored: bool,
-    config: &Config,
-    num_threads: Option<usize>,
-) -> Result<TestHandle, RunError> {
-    info!("running {}", test.path().display());
-    let _ = match test.manifest_dir() {
-        Some(md) => env::set_current_dir(&md),
-        None => env::set_current_dir(&config.root()),
-    };
-
+fn get_env_vars(test: &TestBinary, config: &Config) -> Vec<(String, String)> {
     let mut envars: Vec<(String, String)> = Vec::new();
 
     for (key, value) in env::vars() {
+        // Avoid adding it twice
+        if key == "LD_LIBRARY_PATH" && test.has_linker_paths() {
+            continue;
+        }
         envars.push((key.to_string(), value.to_string()));
     }
-    let mut argv = vec![];
-    if ignored {
-        argv.push("--ignored".to_string());
-    }
     if config.verbose {
         envars.push(("RUST_BACKTRACE".to_string(), "1".to_string()));
     }
-    argv.extend_from_slice(&config.varargs);
-    if config.color != Color::Auto {
-        argv.push("--color".to_string());
-        argv.push(config.color.to_string().to_ascii_lowercase());
-    }
-    if test.is_test_type()
-        && !config.implicit_test_threads
-        && !config.varargs.iter().any(|x| x.contains("--test-threads"))
-    {
-        if let Some(threads) = num_threads {
-            argv.push("--test-threads".to_string());
-            argv.push(threads.to_string());
-        }
-    }
-
     if let Some(s) = test.pkg_name() {
         envars.push(("CARGO_PKG_NAME".to_string(), s.to_string()));
     }
@@ -215,8 +190,54 @@ fn execute_test(
     if test.has_linker_paths() {
         envars.push(("LD_LIBRARY_PATH".to_string(), test.ld_library_path()));
     }
-    debug!("Env vars: {:?}", envars);
-    debug!("Args: {:?}", argv);
+
+    envars
+}
+
+/// Launches the test executable
+fn execute_test(
+    test: &TestBinary,
+    ignored: bool,
+    config: &Config,
+    num_threads: Option<usize>,
+) -> Result<TestHandle, RunError> {
+    info!("running {}", test.path().display());
+    let _ = match test.manifest_dir() {
+        Some(md) => env::set_current_dir(&md),
+        None => env::set_current_dir(&config.root()),
+    };
+
+    debug!("Current working dir: {:?}", env::current_dir());
+
+    let mut envars = get_env_vars(test, config);
+
+    let mut argv = vec![];
+    if ignored {
+        argv.push("--ignored".to_string());
+    }
+    argv.extend_from_slice(&config.varargs);
+    if config.color != Color::Auto {
+        argv.push("--color".to_string());
+        argv.push(config.color.to_string().to_ascii_lowercase());
+    }
+    let no_test_env = if let Ok(threads) = env::var("RUST_TEST_THREADS") {
+        envars.push(("RUST_TEST_THREADS".to_string(), threads));
+        false
+    } else {
+        true
+    };
+
+    if no_test_env
+        && test.is_test_type()
+        && !config.implicit_test_threads
+        && !config.varargs.iter().any(|x| x.contains("--test-threads"))
+    {
+        if let Some(threads) = num_threads {
+            argv.push("--test-threads".to_string());
+            argv.push(threads.to_string());
+        }
+    }
+
     match config.engine() {
         TraceEngine::Llvm => {
             // Used for llvm coverage to avoid report naming clashes TODO could have clashes
@@ -225,6 +246,8 @@ fn execute_test(
                 "LLVM_PROFILE_FILE".to_string(),
                 format!("{}_%p.profraw", test.file_name()),
             ));
+            debug!("Env vars: {:?}", envars);
+            debug!("Args: {:?}", argv);
             let mut child = Command::new(test.path());
             child.envs(envars).args(&argv);
 
@@ -234,6 +257,8 @@ fn execute_test(
         #[cfg(target_os = "linux")]
         TraceEngine::Ptrace => {
             argv.insert(0, test.path().display().to_string());
+            debug!("Env vars: {:?}", envars);
+            debug!("Args: {:?}", argv);
             execute(test.path(), &argv, envars.as_slice())
         }
         e => Err(RunError::Engine(format!(
@@ -242,3 +267,40 @@ fn execute_test(
         ))),
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use std::path::PathBuf;
+
+    #[test]
+    fn check_ld_library_path_correct() {
+        let mut binary = TestBinary::new(PathBuf::from("dummy"), None);
+        let default_config = Config::default();
+
+        let vars = get_env_vars(&binary, &default_config);
+
+        if let Some(ld) = vars
+            .iter()
+            .find(|(key, _)| key == "LD_LIBRARY_PATH")
+            .map(|(_, val)| val)
+        {
+            let sys = env::var("LD_LIBRARY_PATH").unwrap();
+            assert_eq!(ld, &sys);
+        }
+
+        binary
+            .linker_paths
+            .push(PathBuf::from("/usr/local/lib/foo"));
+
+        let vars = get_env_vars(&binary, &default_config);
+        let res = vars
+            .iter()
+            .find(|(key, _)| key == "LD_LIBRARY_PATH")
+            .map(|(_, val)| val);
+
+        assert!(res.is_some());
+        let res = res.unwrap();
+        assert!(res.contains("/usr/local/lib/foo"));
+    }
+}
