@@ -91,7 +91,7 @@ fn line_analysis_works() {
     assert!(!la.should_ignore(0));
     assert!(!la.should_ignore(10));
 
-    la.add_to_ignore(&[3, 4, 10]);
+    la.add_to_ignore([3, 4, 10]);
     assert!(la.should_ignore(3));
     assert!(la.should_ignore(4));
     assert!(la.should_ignore(10));
@@ -1394,3 +1394,49 @@ fn single_line_callables() {
     assert!(!lines.ignore.contains(&Lines::Line(13)));
     assert!(!lines.ignore.contains(&Lines::Line(14)));
 }
+
+#[test]
+fn visit_generics() {
+    let config = Config::default();
+    let ctx = Context {
+        config: &config,
+        file_contents: "fn blah<T>(t: T)  
+        where
+            T: Clone,
+            T: Eq
+        {
+            println!(\"{:?}\", t.clone());
+        }
+        
+        pub trait Foo<T> // 9
+        where
+            T: Clone
+        {
+            fn cloney(&self) -> Self {
+                self.clone()
+            }
+        }
+
+        impl<T> Foo<T> for T // 18
+        where
+            T: Clone
+        {}
+        ",
+        file: Path::new(""),
+        ignore_mods: RefCell::new(HashSet::new()),
+    };
+    let parser = parse_file(ctx.file_contents).unwrap();
+    let mut analysis = SourceAnalysis::new();
+    analysis.process_items(&parser.items, &ctx);
+    let lines = analysis.get_line_analysis(ctx.file.to_path_buf());
+    assert!(lines.ignore.contains(&Lines::Line(2)));
+    assert!(lines.ignore.contains(&Lines::Line(3)));
+    assert!(lines.ignore.contains(&Lines::Line(4)));
+    assert!(lines.ignore.contains(&Lines::Line(3)));
+
+    assert!(lines.ignore.contains(&Lines::Line(10)));
+    assert!(lines.ignore.contains(&Lines::Line(11)));
+
+    assert!(lines.ignore.contains(&Lines::Line(19)));
+    assert!(lines.ignore.contains(&Lines::Line(20)));
+}
