@@ -66,13 +66,17 @@ impl<'a> StateData for LlvmInstrumentedData<'a> {
         unreachable!();
     }
 
+    fn last_wait_attempt(&mut self) -> Result<Option<TestState>, RunError> {
+        unreachable!();
+    }
+
     fn wait(&mut self) -> Result<Option<TestState>, RunError> {
         if let Some(parent) = self.process.as_mut() {
             match parent.child.wait() {
                 Ok(exit) => {
                     let profraws = fs::read_dir(self.config.root())?
                         .into_iter()
-                        .filter_map(|x| x.ok())
+                        .filter_map(Result::ok)
                         .filter(|x| {
                             x.path().is_file()
                                 && x.path().extension() == Some(OsStr::new("profraw"))
