@@ -1,13 +1,15 @@
 use crate::utils::get_test_path;
 use cargo_tarpaulin::config::{Config, RunType};
 use cargo_tarpaulin::launch_tarpaulin;
+use rusty_fork::rusty_fork_test;
 use std::env;
 use std::time::Duration;
 
+rusty_fork_test! {
 #[test]
 fn doc_test_env() {
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let test_dir = get_test_path("doctest_env");
     env::set_current_dir(&test_dir).unwrap();
@@ -27,7 +29,7 @@ fn doc_test_env() {
 fn doc_test_coverage() {
     let mut config = Config::default();
     config.verbose = true;
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let test_dir = get_test_path("doc_coverage");
     env::set_current_dir(&test_dir).unwrap();
@@ -54,7 +56,7 @@ fn doc_test_coverage() {
 fn doc_test_panics() {
     let mut config = Config::default();
     config.verbose = true;
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let test_dir = get_test_path("doctest_should_panic");
     env::set_current_dir(&test_dir).unwrap();
@@ -81,7 +83,7 @@ fn doc_test_panics() {
 fn doc_test_panics_workspace() {
     let mut config = Config::default();
     config.verbose = true;
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let test_dir = get_test_path("doctest_workspace_should_panic");
     env::set_current_dir(&test_dir).unwrap();
@@ -108,7 +110,7 @@ fn doc_test_panics_workspace() {
 fn doc_test_compile_fail() {
     let mut config = Config::default();
     config.verbose = true;
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let test_dir = get_test_path("doctest_compile_fail_fail");
     env::set_current_dir(&test_dir).unwrap();
@@ -124,7 +126,7 @@ fn doc_test_compile_fail() {
 fn doc_test_no_run() {
     let mut config = Config::default();
     config.verbose = true;
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let test_dir = get_test_path("doctest_norun");
     env::set_current_dir(&test_dir).unwrap();
@@ -136,3 +138,4 @@ fn doc_test_no_run() {
     let (_, ret) = launch_tarpaulin(&config, &None).unwrap();
     assert_eq!(ret, 0);
 }
+}
