@@ -2,13 +2,16 @@ use crate::utils::get_test_path;
 use cargo_tarpaulin::config::Config;
 use cargo_tarpaulin::launch_tarpaulin;
 use cargo_tarpaulin::traces::CoverageStat;
+use rusty_fork::rusty_fork_test;
 use std::env;
 use std::time::Duration;
 
+rusty_fork_test! {
+
 #[test]
 fn simple_project_coverage() {
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
     config.test_timeout = Duration::from_secs(60);
     let restore_dir = env::current_dir().unwrap();
     let test_dir = get_test_path("simple_project");
@@ -26,7 +29,6 @@ fn simple_project_coverage() {
     assert_eq!(unused_lines, 3);
     let unused_hits = res
         .get_child_traces(&unused_file)
-        .iter()
         .map(|x| x.line)
         .collect::<Vec<_>>();
 
@@ -37,7 +39,7 @@ fn simple_project_coverage() {
 
     let lib_file = test_dir.join("src/lib.rs");
     let lib_traces = res.get_child_traces(&lib_file);
-    for l in &lib_traces {
+    for l in lib_traces {
         if l.line == 6 {
             assert_eq!(CoverageStat::Line(0), l.stats);
         } else if l.line == 8 {
@@ -50,7 +52,7 @@ fn simple_project_coverage() {
 fn debug_info_0() {
     // From issue #601
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
     let restore_dir = env::current_dir().unwrap();
     let test_dir = get_test_path("simple_project");
     env::set_current_dir(&test_dir).unwrap();
@@ -71,7 +73,7 @@ fn debug_info_0() {
 #[test]
 fn test_threads_1() {
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
     let restore_dir = env::current_dir().unwrap();
     let test_dir = get_test_path("simple_project");
     env::set_current_dir(&test_dir).unwrap();
@@ -87,7 +89,7 @@ fn test_threads_1() {
 
     let lib_file = test_dir.join("src/lib.rs");
     let lib_traces = res.get_child_traces(&lib_file);
-    for l in &lib_traces {
+    for l in lib_traces {
         if l.line == 6 {
             assert_eq!(CoverageStat::Line(0), l.stats);
         } else if l.line == 8 {
@@ -95,3 +97,5 @@ fn test_threads_1() {
         }
     }
 }
+
+}
