@@ -1,12 +1,15 @@
 use crate::utils::get_test_path;
 use cargo_tarpaulin::config::{Config, ConfigWrapper, Mode, RunType};
+use cargo_tarpaulin::event_log::EventLog;
 use cargo_tarpaulin::launch_tarpaulin;
 use cargo_tarpaulin::path_utils::*;
 use cargo_tarpaulin::traces::TraceMap;
 use clap::App;
+use rusty_fork::rusty_fork_test;
+use std::collections::HashSet;
 use std::env;
+use std::fs;
 use std::path::Path;
-use std::process::Command;
 use std::time::Duration;
 
 #[cfg(nightly)]
@@ -32,8 +35,8 @@ pub fn check_percentage_with_cli_args(minimum_coverage: f64, has_lines: bool, ar
 
     let mut configs = ConfigWrapper::from(&matches).0;
     let mut res = TraceMap::new();
-    for config in configs.iter_mut() {
-        config.force_clean = false;
+    for config in &mut configs {
+        config.set_clean(false);
         let (t, _) = launch_tarpaulin(config, &None).unwrap();
         res.merge(&t);
     }
@@ -62,13 +65,20 @@ pub fn check_percentage_with_config(
     env::set_current_dir(&test_dir).unwrap();
     config.manifest = test_dir;
     config.manifest.push("Cargo.toml");
-    config.force_clean = false;
+    config.set_clean(false);
 
     // Note to contributors. If an integration test fails, uncomment this to be able to see the
     // tarpaulin logs
     //cargo_tarpaulin::setup_logging(true, true);
+    let event_log = if config.dump_traces {
+        let mut paths = HashSet::new();
+        paths.insert(config.manifest.clone());
+        Some(EventLog::new(paths))
+    } else {
+        None
+    };
 
-    let (res, ret) = launch_tarpaulin(&config, &None).unwrap();
+    let (res, ret) = launch_tarpaulin(&config, &event_log).unwrap();
     assert_eq!(ret, 0);
 
     env::set_current_dir(restore_dir).unwrap();
@@ -87,15 +97,17 @@ pub fn check_percentage_with_config(
 
 pub fn check_percentage(project_name: &str, minimum_coverage: f64, has_lines: bool) {
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
     check_percentage_with_config(project_name, minimum_coverage, has_lines, config);
 }
 
+rusty_fork_test! {
+
 #[test]
 fn incorrect_manifest_path() {
     let mut config = Config::default();
     config.manifest.push("__invalid_dir__");
-    config.force_clean = false;
+    config.set_clean(false);
     let launch = launch_tarpaulin(&config, &None);
     assert!(launch.is_err());
 }
@@ -104,7 +116,7 @@ fn incorrect_manifest_path() {
 fn proc_macro_link() {
     let mut config = Config::default();
     config.test_timeout = Duration::from_secs(60);
-    config.force_clean = false;
+    config.set_clean(false);
     let test_dir = get_test_path("proc_macro");
     config.manifest = test_dir.join("Cargo.toml");
     assert!(launch_tarpaulin(&config, &None).is_ok());
@@ -196,6 +208,17 @@ fn config_file_coverage() {
     check_percentage_with_cli_args(0.0f64, true, &args);
 }
 
+#[test]
+fn issue_966_follow_exec() {
+    let test_dir = get_test_path("follow_exec_issue966");
+    let args = vec![
+        "tarpaulin".to_string(),
+        "--root".to_string(),
+        test_dir.display().to_string(),
+    ];
+    check_percentage_with_cli_args(1.0f64, true, &args);
+}
+
 #[test]
 fn rustflags_config_coverage() {
     let test_dir = get_test_path("multiple_rustflags");
@@ -221,7 +244,7 @@ fn benchmark_coverage() {
     check_percentage(test, 0.0f64, true);
 
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
     config.run_types = vec![RunType::Benchmarks];
     check_percentage_with_config(test, 1.0f64, true, config);
 }
@@ -230,7 +253,7 @@ fn benchmark_coverage() {
 fn cargo_run_coverage() {
     let mut config = Config::default();
     config.command = Mode::Build;
-    config.force_clean = false;
+    config.set_clean(false);
     check_percentage_with_config("run_coverage", 1.0f64, true, config);
 }
 
@@ -241,7 +264,7 @@ fn examples_coverage() {
 
     let mut config = Config::default();
     config.run_types = vec![RunType::Examples];
-    config.force_clean = false;
+    config.set_clean(false);
     check_percentage_with_config(test, 1.0f64, true, config.clone());
 
     config.run_types.clear();
@@ -282,7 +305,7 @@ fn cargo_home_filtering() {
 
     let mut config = Config::default();
     config.test_timeout = Duration::from_secs(60);
-    config.force_clean = false;
+    config.set_clean(false);
     let restore_dir = env::current_dir().unwrap();
     let test_dir = get_test_path("HttptestAndReqwest");
     env::set_current_dir(&test_dir).unwrap();
@@ -291,10 +314,11 @@ fn cargo_home_filtering() {
 
     env::set_var("CARGO_HOME", new_home.display().to_string());
     let run = launch_tarpaulin(&config, &None);
+    let _ = fs::remove_dir_all(&new_home);
     match previous {
         Ok(s) => env::set_var("CARGO_HOME", s),
         Err(_) => {
-            let _ = Command::new("unset").args(&["CARGO_HOME"]).output();
+            let _ = env::remove_var("CARGO_HOME");
         }
     }
     let (res, _) = run.unwrap();
@@ -309,7 +333,7 @@ fn rustflags_handling() {
     check_percentage("rustflags", 1.0f64, true);
     env::set_var("RUSTFLAGS", "--cfg=foo");
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
 
     let restore_dir = env::current_dir().unwrap();
     let test_dir = get_test_path("rustflags");
@@ -331,7 +355,8 @@ fn rustflags_handling() {
 fn follow_exes_down() {
     let mut config = Config::default();
     config.follow_exec = true;
-    config.force_clean = false;
+    config.dump_traces = true;
+    config.set_clean(false);
     check_percentage_with_config("follow_exe", 1.0f64, true, config);
 }
 
@@ -362,7 +387,7 @@ fn no_test_args() {
 fn dot_rs_in_dir_name() {
     // issue #857
     let mut config = Config::default();
-    config.force_clean = false;
+    config.set_clean(false);
 
     let restore_dir = env::current_dir().unwrap();
     let test_dir = get_test_path("not_a_file.rs");
@@ -379,3 +404,15 @@ fn dot_rs_in_dir_name() {
         assert!(dir.path().is_file());
     }
 }
+
+#[test]
+fn kill_used_in_test() {
+    let mut config = Config::default();
+    config.follow_exec = true;
+    config.set_clean(false);
+    // Currently 2 false negatives, but if it was only covering the integration test max coverage
+    // is 75% so this is high enough to prove it works
+    check_percentage_with_config("kill_proc", 0.9f64, true, config);
+}
+
+}
